:mod:`bdbcontrib.predictors.predictor`: Foreign predictor interface
===================================================================

PRELIMINARY!

.. automodule:: bdbcontrib.predictors.predictor
 :members:
